#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

// mp_bitcnt_t unsigned long int

//DATA(__gmp_allocate_func, 
//GO(__gmp_asprintf, 
//GO(__gmp_asprintf_final, 
//DATA(__gmp_asprintf_funs, 
//GO(__gmp_asprintf_memory, 
//GO(__gmp_asprintf_reps, 
//GO(__gmp_assert_fail, 
//GO(__gmp_assert_header, 
//GO(__gmp_default_allocate, 
//DATA(__gmp_default_fp_limb_precision, 
//GO(__gmp_default_free, 
//GO(__gmp_default_reallocate, 
//GO(__gmp_divide_by_zero, 
//GO(__gmp_doprnt, 
//GO(__gmp_doprnt_integer, 
//GO(__gmp_doprnt_mpf2, 
//GO(__gmp_doscan, 
//DATAB(__gmp_errno, 
//GO(__gmp_exception, 
//GO(__gmp_extract_double, 
//GO(__gmpf_abs, 
//GO(__gmpf_add, 
//GO(__gmpf_add_ui, 
//GO(__gmpf_ceil, 
//GO(__gmpf_clear, 
//GO(__gmpf_clears, 
//GO(__gmpf_cmp, 
//GO(__gmpf_cmp_d, 
//GO(__gmpf_cmp_si, 
//GO(__gmpf_cmp_ui, 
//GO(__gmpf_cmp_z, 
//GO(__gmpf_div, 
//GO(__gmpf_div_2exp, 
//GO(__gmpf_div_ui, 
//GO(__gmpf_dump, 
//GO(__gmpf_eq, 
//GO(__gmpf_fits_sint_p, 
//GO(__gmpf_fits_slong_p, 
//GO(__gmpf_fits_sshort_p, 
//GO(__gmpf_fits_uint_p, 
//GO(__gmpf_fits_ulong_p, 
//GO(__gmpf_fits_ushort_p, 
//GO(__gmpf_floor, 
//GO(__gmpf_get_d, 
//GO(__gmpf_get_d_2exp, 
//GO(__gmpf_get_default_prec, 
//GO(__gmpf_get_prec, 
//GO(__gmpf_get_si, 
//GO(__gmpf_get_str, 
//GO(__gmpf_get_ui, 
//GO(__gmpf_init, 
//GO(__gmpf_init2, 
//GO(__gmpf_inits, 
//GO(__gmpf_init_set, 
//GO(__gmpf_init_set_d, 
//GO(__gmpf_init_set_si, 
//GO(__gmpf_init_set_str, 
//GO(__gmpf_init_set_ui, 
//GO(__gmpf_inp_str, 
//GO(__gmpf_integer_p, 
//GO(__gmpf_mul, 
//GO(__gmpf_mul_2exp, 
//GO(__gmpf_mul_ui, 
//GO(__gmpf_neg, 
//GO(__gmpf_out_str, 
//GO(__gmpf_pow_ui, 
//GO(__gmp_fprintf, 
//DATA(__gmp_fprintf_funs, 
//GO(__gmpf_random2, 
//DATA(__gmp_free_func, 
//GO(__gmpf_reldiff, 
//GO(__gmp_fscanf, 
//DATA(__gmp_fscanf_funs, 
//GO(__gmpf_set, 
//GO(__gmpf_set_d, 
//GO(__gmpf_set_default_prec, 
//GO(__gmpf_set_prec, 
//GO(__gmpf_set_prec_raw, 
//GO(__gmpf_set_q, 
//GO(__gmpf_set_si, 
//GO(__gmpf_set_str, 
//GO(__gmpf_set_ui, 
//GO(__gmpf_set_z, 
//GO(__gmpf_size, 
//GO(__gmpf_sqrt, 
//GO(__gmpf_sqrt_ui, 
//GO(__gmpf_sub, 
//GO(__gmpf_sub_ui, 
//GO(__gmpf_swap, 
//GO(__gmpf_trunc, 
//GO(__gmpf_ui_div, 
//GO(__gmpf_ui_sub, 
//GO(__gmpf_urandomb, 
GOM(__gmp_get_memory_functions, vFEppp)
//GO(__gmp_init_primesieve, 
//GO(__gmp_invalid_operation, 
//DATAB(__gmp_junk, 
//GO(__gmp_mt_recalc_buffer, 
//GO(__gmpn_add, 
//GO(__gmpn_add_1, 
//GO(__gmpn_add_err1_n, 
//GO(__gmpn_add_err2_n, 
//GO(__gmpn_add_err3_n, 
//GO(__gmpn_addlsh1_n, 
//GO(__gmpn_addlsh2_n, 
GO(__gmpn_addmul_1, LFppLL)
GO(__gmpn_add_n, LFpppL)
//GO(__gmpn_add_nc, 
//GO(__gmpn_add_n_sub_n, 
//GO(__gmpn_and_n, 
//GO(__gmpn_andn_n, 
//GO(__gmpn_bc_mulmod_bnm1, 
//GO(__gmpn_bc_set_str, 
//GO(__gmpn_bdiv_dbm1c, 
//GO(__gmpn_bdiv_q, 
//GO(__gmpn_bdiv_q_1, 
//GO(__gmpn_bdiv_q_itch, 
//GO(__gmpn_bdiv_qr, 
//GO(__gmpn_bdiv_qr_itch, 
//GO(__gmpn_binvert, 
//GO(__gmpn_binvert_itch, 
//GO(__gmpn_broot, 
//GO(__gmpn_brootinv, 
//GO(__gmpn_broot_invm1, 
//GO(__gmpn_bsqrt, 
//GO(__gmpn_bsqrtinv, 
//GO(__gmpn_cmp, 
GO(__gmpn_cnd_add_n, LFLpppL)
GO(__gmpn_cnd_sub_n, LFLpppL)
GO(__gmpn_cnd_swap, vFippL)
//GO(__gmpn_com, 
//GO(__gmpn_compute_powtab, 
GO(__gmpn_copyd, vFppL)
GO(__gmpn_copyi, vFppL)
//GO(__gmpn_dcpi1_bdiv_q, 
//GO(__gmpn_dcpi1_bdiv_qr, 
//GO(__gmpn_dcpi1_bdiv_qr_n, 
//GO(__gmpn_dcpi1_bdiv_qr_n_itch, 
//GO(__gmpn_dcpi1_divappr_q, 
//GO(__gmpn_dcpi1_div_q, 
//GO(__gmpn_dcpi1_div_qr, 
//GO(__gmpn_dcpi1_div_qr_n, 
//GO(__gmpn_dc_set_str, 
//GO(__gmpn_divexact, 
//GO(__gmpn_divexact_1, 
//GO(__gmpn_divexact_by3, 
//GO(__gmpn_divexact_by3c, 
//GO(__gmpn_divisible_p, 
//GO(__gmpn_divmod_1, 
//GO(__gmpn_div_q, 
//GO(__gmpn_div_qr_1, 
//GO(__gmpn_div_qr_1n_pi1, 
//GO(__gmpn_div_qr_2, 
//GO(__gmpn_div_qr_2n_pi1, 
//GO(__gmpn_div_qr_2u_pi1, 
//GO(__gmpn_divrem, 
//GO(__gmpn_divrem_1, 
//GO(__gmpn_divrem_2, 
//GO(__gmpn_dump, 
//GO(__gmp_nextprime, 
//GO(__gmpn_fft_best_k, 
//GO(__gmpn_fft_next_size, 
//GO(__gmpn_fib2m, 
//GO(__gmpn_fib2_ui, 
//GO(__gmpn_gcd, 
//GO(__gmpn_gcd_1, 
//GO(__gmpn_gcd_11, 
//GO(__gmpn_gcd_22, 
//GO(__gmpn_gcdext, 
//GO(__gmpn_gcdext_1, 
//GO(__gmpn_gcdext_hook, 
//GO(__gmpn_gcdext_lehmer_n, 
//GO(__gmpn_gcd_subdiv_step, 
//GO(__gmpn_get_d, 
//GO(__gmpn_get_str, 
//GO(__gmpn_hamdist, 
//GO(__gmpn_hgcd, 
//GO(__gmpn_hgcd2, 
//GO(__gmpn_hgcd2_jacobi, 
//GO(__gmpn_hgcd_appr, 
//GO(__gmpn_hgcd_appr_itch, 
//GO(__gmpn_hgcd_itch, 
//GO(__gmpn_hgcd_jacobi, 
//GO(__gmpn_hgcd_matrix_adjust, 
//GO(__gmpn_hgcd_matrix_init, 
//GO(__gmpn_hgcd_matrix_mul, 
//GO(__gmpn_hgcd_matrix_mul_1, 
//GO(__gmpn_hgcd_matrix_update_q, 
//GO(__gmpn_hgcd_mul_matrix1_vector, 
//GO(__gmpn_hgcd_reduce, 
//GO(__gmpn_hgcd_reduce_itch, 
//GO(__gmpn_hgcd_step, 
//GO(__gmpn_invert, 
//GO(__gmpn_invertappr, 
//GO(__gmpn_invert_limb, 
//GO(__gmpn_ior_n, 
//GO(__gmpn_iorn_n, 
//GO(__gmpn_jacobi_2, 
//GO(__gmpn_jacobi_base, 
//GO(__gmpn_jacobi_n, 
//GO(__gmpn_lshift, 
//GO(__gmpn_lshiftc, 
//GO(__gmpn_matrix22_mul, 
//GO(__gmpn_matrix22_mul1_inverse_vector, 
//GO(__gmpn_matrix22_mul_itch, 
//GO(__gmpn_mod_1, 
//GO(__gmpn_mod_1_1p, 
//GO(__gmpn_mod_1_1p_cps, 
//GO(__gmpn_mod_1s_2p, 
//GO(__gmpn_mod_1s_2p_cps, 
//GO(__gmpn_mod_1s_3p, 
//GO(__gmpn_mod_1s_3p_cps, 
//GO(__gmpn_mod_1s_4p, 
//GO(__gmpn_mod_1s_4p_cps, 
//GO(__gmpn_mod_34lsub1, 
//GO(__gmpn_modexact_1c_odd, 
//GO(__gmpn_mu_bdiv_q, 
//GO(__gmpn_mu_bdiv_q_itch, 
//GO(__gmpn_mu_bdiv_qr, 
//GO(__gmpn_mu_bdiv_qr_itch, 
//GO(__gmpn_mu_divappr_q, 
//GO(__gmpn_mu_divappr_q_itch, 
//GO(__gmpn_mu_div_q, 
//GO(__gmpn_mu_div_q_itch, 
//GO(__gmpn_mu_div_qr, 
//GO(__gmpn_mu_div_qr_itch, 
//GO(__gmpn_mul, 
GO(__gmpn_mul_1, LFppLL)
//GO(__gmpn_mul_1c, 
//GO(__gmpn_mul_basecase, 
//GO(__gmpn_mul_fft, 
//GO(__gmpn_mullo_basecase, 
//GO(__gmpn_mullo_n, 
//GO(__gmpn_mulmid, 
//GO(__gmpn_mulmid_basecase, 
//GO(__gmpn_mulmid_n, 
//GO(__gmpn_mulmod_bnm1, 
//GO(__gmpn_mulmod_bnm1_next_size, 
GO(__gmpn_mul_n, vFpppL)
//GO(__gmpn_nand_n, 
//GO(__gmpn_neg, 
//GO(__gmpn_ni_invertappr, 
//GO(__gmpn_nior_n, 
//GO(__gmpn_nussbaumer_mul, 
//GO(__gmpn_perfect_power_p, 
GO(__gmpn_perfect_square_p, iFpL)
//GO(__gmpn_pi1_bdiv_q_1, 
//GO(__gmpn_popcount, 
//GO(__gmpn_pow_1, 
//GO(__gmpn_powlo, 
//GO(__gmpn_powm, 
//GO(__gmpn_preinv_divrem_1, 
//GO(__gmpn_preinv_mod_1, 
//GO(__gmpn_preinv_mu_div_qr, 
//GO(__gmpn_preinv_mu_div_qr_itch, 
//GO(__gmpn_random, 
//GO(__gmpn_random2, 
//GO(__gmpn_redc_1, 
//GO(__gmpn_redc_2, 
//GO(__gmpn_redc_n, 
//GO(__gmpn_remove, 
//GO(__gmpn_rootrem, 
//GO(__gmpn_rsblsh1_n, 
//GO(__gmpn_rsblsh2_n, 
//GO(__gmpn_rsh1add_n, 
//GO(__gmpn_rsh1sub_n, 
GO(__gmpn_rshift, LFppLu)
//GO(__gmpn_sbpi1_bdiv_q, 
//GO(__gmpn_sbpi1_bdiv_qr, 
//GO(__gmpn_sbpi1_bdiv_r, 
//GO(__gmpn_sbpi1_divappr_q, 
//GO(__gmpn_sbpi1_div_q, 
//GO(__gmpn_sbpi1_div_qr, 
//GO(__gmpn_scan0, 
//GO(__gmpn_scan1, 
GO(__gmpn_sec_add_1, LFppLL)
GO(__gmpn_sec_add_1_itch, LFL)
//GO(__gmpn_sec_div_qr, 
//GO(__gmpn_sec_div_qr_itch, 
GO(__gmpn_sec_div_r, LFppLpLL)
GO(__gmpn_sec_div_r_itch, LFL)
GO(__gmpn_sec_invert, iFpppLL)
GO(__gmpn_sec_invert_itch, LFL)
GO(__gmpn_sec_mul, vFpppLp)
GO(__gmpn_sec_mul_itch, LFL)
//GO(__gmpn_sec_pi1_div_qr, 
//GO(__gmpn_sec_pi1_div_r, 
GO(__gmpn_sec_powm, vFppLpLpLp)
GO(__gmpn_sec_powm_itch, LFLL)
//GO(__gmpn_sec_sqr, 
//GO(__gmpn_sec_sqr_itch, 
GO(__gmpn_sec_sub_1, LFppLL)
//GO(__gmpn_sec_sub_1_itch, 
GO(__gmpn_sec_tabselect, vFppLLL)
//GO(__gmpn_set_str, 
//GO(__gmpn_sizeinbase, 
GO(__gmpn_sqr, vFppL)
//GO(__gmpn_sqr_basecase, 
//GO(__gmpn_sqr_diag_addlsh1, 
//GO(__gmpn_sqrlo, 
//GO(__gmpn_sqrlo_basecase, 
//GO(__gmpn_sqrmod_bnm1, 
//GO(__gmpn_sqrmod_bnm1_next_size, 
//GO(__gmpn_sqrtrem, 
//GO(__gmpn_strongfibo, 
//GO(__gmpn_sub, 
//GO(__gmpn_sub_1, 
//GO(__gmpn_sub_err1_n, 
//GO(__gmpn_sub_err2_n, 
//GO(__gmpn_sub_err3_n, 
//GO(__gmpn_sublsh1_n, 
//GO(__gmpn_sublsh2_n, 
GO(__gmpn_submul_1, LFppLL)
GO(__gmpn_sub_n, LFpppL)
//GO(__gmpn_sub_nc, 
//GO(__gmpn_tdiv_qr, 
//GO(__gmpn_toom22_mul, 
//GO(__gmpn_toom2_sqr, 
//GO(__gmpn_toom32_mul, 
//GO(__gmpn_toom33_mul, 
//GO(__gmpn_toom3_sqr, 
//GO(__gmpn_toom42_mul, 
//GO(__gmpn_toom42_mulmid, 
//GO(__gmpn_toom43_mul, 
//GO(__gmpn_toom44_mul, 
//GO(__gmpn_toom4_sqr, 
//GO(__gmpn_toom52_mul, 
//GO(__gmpn_toom53_mul, 
//GO(__gmpn_toom54_mul, 
//GO(__gmpn_toom62_mul, 
//GO(__gmpn_toom63_mul, 
//GO(__gmpn_toom6h_mul, 
//GO(__gmpn_toom6_sqr, 
//GO(__gmpn_toom8h_mul, 
//GO(__gmpn_toom8_sqr, 
//GO(__gmpn_toom_couple_handling, 
//GO(__gmpn_toom_eval_dgr3_pm1, 
//GO(__gmpn_toom_eval_dgr3_pm2, 
//GO(__gmpn_toom_eval_pm1, 
//GO(__gmpn_toom_eval_pm2, 
//GO(__gmpn_toom_eval_pm2exp, 
//GO(__gmpn_toom_eval_pm2rexp, 
//GO(__gmpn_toom_interpolate_12pts, 
//GO(__gmpn_toom_interpolate_16pts, 
//GO(__gmpn_toom_interpolate_5pts, 
//GO(__gmpn_toom_interpolate_6pts, 
//GO(__gmpn_toom_interpolate_7pts, 
//GO(__gmpn_toom_interpolate_8pts, 
//GO(__gmpn_trialdiv, 
//GO(__gmpn_xnor_n, 
//GO(__gmpn_xor_n, 
GO(__gmpn_zero, vFpL)
//GO(__gmpn_zero_p, 
//GO(__gmp_obstack_printf, 
//DATA(__gmp_obstack_printf_funs, 
//GO(__gmp_obstack_vprintf, 
//GO(__gmp_primesieve, 
//GO(__gmp_printf, 
//GO(__gmpq_abs, 
//GO(__gmpq_add, 
//GO(__gmpq_canonicalize, 
//GO(__gmpq_clear, 
//GO(__gmpq_clears, 
//GO(__gmpq_cmp, 
//GO(__gmpq_cmp_si, 
//GO(__gmpq_cmp_ui, 
//GO(__gmpq_cmp_z, 
//GO(__gmpq_div, 
//GO(__gmpq_div_2exp, 
//GO(__gmpq_equal, 
//GO(__gmpq_get_d, 
//GO(__gmpq_get_den, 
//GO(__gmpq_get_num, 
//GO(__gmpq_get_str, 
//GO(__gmpq_init, 
//GO(__gmpq_inits, 
//GO(__gmpq_inp_str, 
//GO(__gmpq_inv, 
//GO(__gmpq_mul, 
//GO(__gmpq_mul_2exp, 
//GO(__gmpq_neg, 
//GO(__gmpq_out_str, 
//GO(__gmpq_set, 
//GO(__gmpq_set_d, 
//GO(__gmpq_set_den, 
//GO(__gmpq_set_f, 
//GO(__gmpq_set_num, 
//GO(__gmpq_set_si, 
//GO(__gmpq_set_str, 
//GO(__gmpq_set_ui, 
//GO(__gmpq_set_z, 
//GO(__gmpq_sub, 
//GO(__gmpq_swap, 
//GO(__gmp_randclear, 
//GO(__gmp_randclear_mt, 
//GO(__gmp_randget_mt, 
//GO(__gmp_randinit, 
//GO(__gmp_randinit_default, 
//GO(__gmp_randinit_lc_2exp, 
//GO(__gmp_randinit_lc_2exp_size, 
//GO(__gmp_randinit_mt, 
//GO(__gmp_randinit_mt_noseed, 
//GO(__gmp_randinit_set, 
//GO(__gmp_randiset_mt, 
//DATAB(__gmp_rands, 
//GO(__gmp_randseed, 
//GO(__gmp_randseed_ui, 
//DATAB(__gmp_rands_initialized, 
//DATA(__gmp_reallocate_func, 
//GO(__gmp_scanf, 
GOM(__gmp_set_memory_functions, vFEppp)
//GO(__gmp_snprintf, 
//DATA(__gmp_snprintf_funs, 
//GO(__gmp_sprintf, 
//DATA(__gmp_sprintf_funs, 
//GO(__gmp_sqrt_of_negative, 
//GO(__gmp_sscanf, 
//DATA(__gmp_sscanf_funs, 
//GO(__gmp_tmp_reentrant_alloc, 
//GO(__gmp_tmp_reentrant_free, 
//GO(__gmp_urandomb_ui, 
//GO(__gmp_urandomm_ui, 
//GO(__gmp_vasprintf, 
//DATA(__gmp_version, 
//GO(__gmp_vfprintf, 
//GO(__gmp_vfscanf, 
//GO(__gmp_vprintf, 
//GO(__gmp_vscanf, 
//GO(__gmp_vsnprintf, 
//GO(__gmp_vsprintf, 
//GO(__gmp_vsscanf, 
//GO(__gmpz_2fac_ui, 
//GO(__gmpz_abs, 
GO(__gmpz_add, vFppp)
//GO(__gmpz_addmul, 
//GO(__gmpz_addmul_ui, 
GO(__gmpz_add_ui, vFppL)
GO(__gmpz_and, vFppp)
//GO(__gmpz_aorsmul_1, 
//GO(__gmpz_array_init, 
//GO(__gmpz_bin_ui, 
//GO(__gmpz_bin_uiui, 
GO(__gmpz_cdiv_q, vFppp)
//GO(__gmpz_cdiv_q_2exp, 
//GO(__gmpz_cdiv_qr, 
//GO(__gmpz_cdiv_qr_ui, 
//GO(__gmpz_cdiv_q_ui, 
//GO(__gmpz_cdiv_r, 
//GO(__gmpz_cdiv_r_2exp, 
//GO(__gmpz_cdiv_r_ui, 
//GO(__gmpz_cdiv_ui, 
GO(__gmpz_clear, vFp)
//GO(__gmpz_clears, 
//GO(__gmpz_clrbit, 
GO(__gmpz_cmp, iFpp)
//GO(__gmpz_cmpabs, 
//GO(__gmpz_cmpabs_d, 
//GO(__gmpz_cmpabs_ui, 
//GO(__gmpz_cmp_d, 
//GO(__gmpz_cmp_si, 
GO(__gmpz_cmp_ui, iFpu)
GO(__gmpz_com, vFpp)
//GO(__gmpz_combit, 
//GO(__gmpz_congruent_2exp_p, 
GO(__gmpz_congruent_p, iFppp)
//GO(__gmpz_congruent_ui_p, 
//GO(__gmpz_divexact, 
//GO(__gmpz_divexact_gcd, 
//GO(__gmpz_divexact_ui, 
//GO(__gmpz_divisible_2exp_p, 
//GO(__gmpz_divisible_p, 
//GO(__gmpz_divisible_ui_p, 
//GO(__gmpz_dump, 
GO(__gmpz_export, vFppiLiLp)
//GO(__gmpz_fac_ui, 
GO(__gmpz_fdiv_q, vFppp)
GO(__gmpz_fdiv_q_2exp, vFppL)
//GO(__gmpz_fdiv_qr, 
//GO(__gmpz_fdiv_qr_ui, 
//GO(__gmpz_fdiv_q_ui, 
GO(__gmpz_fdiv_r, vFppp)
GO(__gmpz_fdiv_r_2exp, vFppL)
//GO(__gmpz_fdiv_r_ui, 
//GO(__gmpz_fdiv_ui, 
//GO(__gmpz_fib2_ui, 
//GO(__gmpz_fib_ui, 
//GO(__gmpz_fits_sint_p, 
//GO(__gmpz_fits_slong_p, 
//GO(__gmpz_fits_sshort_p, 
//GO(__gmpz_fits_uint_p, 
//GO(__gmpz_fits_ulong_p, 
//GO(__gmpz_fits_ushort_p, 
GO(__gmpz_gcd, vFppp)
//GO(__gmpz_gcdext, 
//GO(__gmpz_gcd_ui, 
//GO(__gmpz_get_d, 
//GO(__gmpz_get_d_2exp, 
//GO(__gmpz_getlimbn, 
//GO(__gmpz_get_si, 
//GO(__gmpz_get_str, 
//GO(__gmpz_get_ui, 
//GO(__gmpz_hamdist, 
GO(__gmpz_import, vFpLiLiLp)
GO(__gmpz_init, vFp)
//GO(__gmpz_init2, 
//GO(__gmpz_inits, 
GO(__gmpz_init_set, vFpp)
//GO(__gmpz_init_set_d, 
//GO(__gmpz_init_set_si, 
GO(__gmpz_init_set_str, iFppi)
GO(__gmpz_init_set_ui, vFpL)
//GO(__gmpz_inp_raw, 
//GO(__gmpz_inp_str, 
//GO(__gmpz_inp_str_nowhite, 
GO(__gmpz_invert, iFppp)
//GO(__gmpz_ior, 
//GO(__gmpz_jacobi, 
//GO(__gmpz_kronecker_si, 
//GO(__gmpz_kronecker_ui, 
GO(__gmpz_lcm, vFppp)
//GO(__gmpz_lcm_ui, 
//GO(__gmpz_legendre, 
GO(__gmpz_limbs_finish, vFpL)
GO(__gmpz_limbs_modify, pFpL)
GO(__gmpz_limbs_read, pFp)
GO(__gmpz_limbs_write, pFpL)
//GO(__gmpz_lucas_mod, 
//GO(__gmpz_lucnum2_ui, 
//GO(__gmpz_lucnum_ui, 
//GO(__gmpz_mfac_uiui, 
//GO(__gmpz_millerrabin, 
GO(__gmpz_mod, vFppp)
GO(__gmpz_mul, vFppp)
GO(__gmpz_mul_2exp, vFppL)
//GO(__gmpz_mul_si, 
GO(__gmpz_mul_ui, vFppL)
//GO(__gmpz_neg, 
//GO(__gmpz_nextprime, 
//GO(__gmpz_n_pow_ui, 
//GO(__gmpz_oddfac_1, 
//GO(__gmpz_out_raw, 
//GO(__gmpz_out_str, 
//GO(__gmpz_perfect_power_p, 
//GO(__gmpz_perfect_square_p, 
//GO(__gmpz_popcount, 
GO(__gmpz_powm, vFpppp)
GO(__gmpz_powm_sec, vFpppp)
GO(__gmpz_powm_ui, vFppLp)
//GO(__gmpz_pow_ui, 
//GO(__gmpz_primorial_ui, 
GO(__gmpz_probab_prime_p, iFpi)
//GO(__gmpz_prodlimbs, 
//GO(__gmpz_random, 
//GO(__gmpz_random2, 
//GO(__gmpz_realloc, 
//GO(__gmpz_realloc2, 
//GO(__gmpz_remove, 
GO(__gmpz_roinit_n, pFppL)
//GO(__gmpz_root, 
//GO(__gmpz_rootrem, 
//GO(__gmpz_rrandomb, 
//GO(__gmpz_scan0, 
GO(__gmpz_scan1, LFpL)
GO(__gmpz_set, vFpp)
GO(__gmpz_setbit, vFpL)
//GO(__gmpz_set_d, 
//GO(__gmpz_set_f, 
//GO(__gmpz_set_q, 
//GO(__gmpz_set_si, 
//GO(__gmpz_set_str, 
GO(__gmpz_set_ui, vFpL)
//GO(__gmpz_si_kronecker, 
//GO(__gmpz_size, 
GO(__gmpz_sizeinbase, LFpi)
GO(__gmpz_sqrt, vFpp)
//GO(__gmpz_sqrtrem, 
//GO(__gmpz_stronglucas, 
GO(__gmpz_sub, vFppp)
GO(__gmpz_submul, vFppp)
GO(__gmpz_submul_ui, vFppL)
GO(__gmpz_sub_ui, vFppu)
//GO(__gmpz_swap, 
//GO(__gmpz_tdiv_q, 
GO(__gmpz_tdiv_q_2exp, vFppL)
GO(__gmpz_tdiv_qr, vFpppp)
//GO(__gmpz_tdiv_qr_ui, 
//GO(__gmpz_tdiv_q_ui, 
//GO(__gmpz_tdiv_r, 
GO(__gmpz_tdiv_r_2exp, vFppL)
//GO(__gmpz_tdiv_r_ui, 
//GO(__gmpz_tdiv_ui, 
GO(__gmpz_tstbit, iFpL)
//GO(__gmpz_ui_kronecker, 
//GO(__gmpz_ui_pow_ui, 
//GO(__gmpz_ui_sub, 
//GO(__gmpz_urandomb, 
//GO(__gmpz_urandomm, 
//GO(__gmpz_xor, 
